.. GraphFlow documentation master file, created by
   sphinx-quickstart on Mon Apr 16 17:58:42 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to GraphFlow's documentation!
=====================================

.. image:: https://travis-ci.org/stephenhky/GraphFlow.svg?branch=master
   :target: https://travis-ci.org/stephenhky/GraphFlow

Contents:

.. toctree::
   :maxdepth: 1

   intro
   news

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

